@@ -136,7 +136,12 @@ DlgAbout::DlgAbout()
             << "Patrick Taels"
             << "armaan"
             << "Karam Assany"
-            << "Anmol Mishra";
+            << "Anmol Mishra"
+            << "Alec Peng"
+            << "Arthur Vimond"
+            << "Johan Jnn"
+            << "Shiraz McClennon"
+            << "Hetarth Jodha";
 
     QStringList specialThanks;
     specialThanks
