@@ -27,11 +27,19 @@ class DlgPrefBeats : public DlgPreferencePage, public Ui::DlgBeatsDlg {
 
   private slots:
     void pluginSelected(int i);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+    void analyzerEnabled(Qt::CheckState state);
+    void fixedtempoEnabled(Qt::CheckState state);
+    void fastAnalysisEnabled(Qt::CheckState state);
+    void slotReanalyzeChanged(Qt::CheckState state);
+    void slotReanalyzeImportedChanged(Qt::CheckState state);
+#else
     void analyzerEnabled(int i);
     void fixedtempoEnabled(int i);
     void fastAnalysisEnabled(int i);
     void slotReanalyzeChanged(int value);
     void slotReanalyzeImportedChanged(int value);
+#endif
 
   private:
     void loadSettings();
